Actions, Resources, and Condition Keys for AWS AppConfig - AWS Identity and Access Management
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.

# Actions, Resources, and Condition Keys for AWS AppConfig

AWS AppConfig (service prefix: `appconfig` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by AWS AppConfig
- Resource Types Defined by AWS AppConfig
- Condition Keys for AWS AppConfig

## Actions Defined by AWS AppConfig

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
CreateApplication | Grants permission to create an application | Write | application* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateConfigurationProfile | Grants permission to create a configuration profile | Write | application* |  |
configurationprofile* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateDeploymentStrategy | Grants permission to create a deployment strategy | Write | deploymentstrategy* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateEnvironment | Grants permission to create an environment | Write | application* |  |
environment* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteApplication | Grants permission to delete an application | Write | application* |  |
DeleteConfigurationProfile | Grants permission to delete a configuration profile | Write | application* |  |
configurationprofile* |  |
DeleteDeploymentStrategy | Grants permission to delete a deployment strategy | Write | deploymentstrategy* |  |
DeleteEnvironment | Grants permission to delete an environment | Write | application* |  |
environment* |  |
GetApplication | Grants permission to view details about an application | Read | application* |  |
| aws:ResourceTag/${TagKey} |
GetConfiguration | Grants permission to view details about a configuration | Read | application* |  |
configurationprofile* |  |
environment* |  |
| aws:ResourceTag/${TagKey} |
GetConfigurationProfile | Grants permission to view details about a configuration profile | Read | application* |  |
configurationprofile* |  |
| aws:ResourceTag/${TagKey} |
GetDeployment | Grants permission to view details about a deployment | Read | application* |  |
deployment* |  |
environment* |  |
| aws:ResourceTag/${TagKey} |
GetDeploymentStrategy | Grants permission to view details about a deployment strategy | Read | deploymentstrategy* |  |
| aws:ResourceTag/${TagKey} |
GetEnvironment | Grants permission to view details about an environment | Read | application* |  |
environment* |  |
| aws:ResourceTag/${TagKey} |
ListApplications | Grants permission to list the applications in your account | List |  |  |
ListConfigurationProfiles | Grants permission to list the configuration profiles for an application | List | application* |  |
ListDeploymentStrategies | Grants permission to list the deployment strategies for your account | List |  |  |
ListDeployments | Grants permission to list the deployments for an environment | List | application* |  |
environment* |  |
ListEnvironments | Grants permission to list the environments for an application | List | application* |  |
ListTagsForResource | Grants permission to view a list of resource tags for a specified resource | Read | application |  |
configurationprofile |  |
deployment |  |
deploymentstrategy |  |
environment |  |
| aws:ResourceTag/${TagKey} |
StartDeployment | Grants permission to initiate a deployment | Write | application* |  |
configurationprofile* |  |
deployment* |  |
deploymentstrategy* |  |
environment* |  |
StopDeployment | Grants permission to stop a deployment | Write | application* |  |
deployment* |  |
environment* |  |
TagResource | Grants permission to tag an appconfig resource. | Tagging | application |  |
configurationprofile |  |
deployment |  |
deploymentstrategy |  |
environment |  |
| aws:TagKeys aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} |
UntagResource | Grants permission to untag an appconfig resource. | Tagging | application |  |
configurationprofile |  |
deployment |  |
deploymentstrategy |  |
environment |  |
| aws:TagKeys |
UpdateApplication | Grants permission to modify an application | Write | application* |  |
| aws:ResourceTag/${TagKey} |
UpdateConfigurationProfile | Grants permission to modify a configuration profile | Write | application* |  |
configurationprofile* |  |
| aws:ResourceTag/${TagKey} |
UpdateDeploymentStrategy | Grants permission to modify a deployment strategy | Write | deploymentstrategy* |  |
| aws:ResourceTag/${TagKey} |
UpdateEnvironment | Grants permission to modify an environment | Write | application* |  |
environment* |  |
| aws:ResourceTag/${TagKey} |
ValidateConfiguration | Grants permission to validate a configuration | Write | application* |  |
configurationprofile* |  |

## Resource Types Defined by AWS AppConfig

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table .

Resource Types | ARN | Condition Keys
--- | --- | ---
application | `arn:$ { Partition}:appconfig:$ { Region}:$ { Account}:application/$ { ApplicationId}` | aws:ResourceTag/${TagKey}
environment | `arn:$ { Partition}:appconfig:$ { Region}:$ { Account}:application/$ { ApplicationId}/environment/$ { EnvironmentId}` | aws:ResourceTag/${TagKey}
configurationprofile | `arn:$ { Partition}:appconfig:$ { Region}:$ { Account}:application/$ { ApplicationId}/configurationprofile/$ { ConfigurationProfileId}` | aws:ResourceTag/${TagKey}
deploymentstrategy | `arn:$ { Partition}:appconfig:$ { Region}:$ { Account}:deploymentstrategy/$ { DeploymentStrategyId}` | aws:ResourceTag/${TagKey}
deployment | `arn:$ { Partition}:appconfig:$ { Region}:$ { Account}:application/$ { ApplicationId}/environment/$ { EnvironmentId}/deployment/$ { DeploymentNumber}` | aws:ResourceTag/${TagKey}

## Condition Keys for AWS AppConfig

AWS AppConfig defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table .

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference .

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/$ { TagKey} | Filters 'Create' requests based on the allowed set of values for a specified tags | String
aws:ResourceTag/$ { TagKey} | Filters access based on a tag key-value pair assigned to the AWS resource | String
aws:TagKeys | Filters 'Create' requests based on whether mandatory tags are included in the request | String